#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
from os import listdir
from os.path import isfile, join
import subprocess

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from builder.ApiBuilder import ApiBuilder
from smartlingApiSdk.Logger import Logger
from smartlingApiSdk.Settings import Settings
import logging

isPython3 =  sys.version_info[:2] >= (3,0)

def assert_diff_is_empty(diff, cmd):
    if diff :
        print ("diff command is:", cmd)
        print (diff)
        err = "Api is changed"
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class testApiChanges:
    api_path = '../smartlingApiSdk/api'
    example_path = '../smartlingApiSdk/example'

    def setUp(self):
        sys.stdout = Logger('python-sdk', Settings.logLevel)

    def tearDown(self):
        pass

    def command(self, cmd):
        process = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE)
        output, error = process.communicate()
        return output

    def fullPath(self, f):
        return join(self.api_path, f)

    def listApis(self):
        return [f for f in os.listdir(self.api_path) if isfile(self.fullPath(f)) and f.endswith('Api.py')]

    def testAll(self):
        for api_file_name in self.listApis():
            api_name = api_file_name[:-6]
            if 'AccountProjects' == api_name:
                api_name = 'Account & Projects'

            if 'JobBatchesV2' == api_name:
                api_name = 'Job Batches V2'

            print ("Cheking:%s" % api_name)
            apisrc = ApiBuilder(api_name).apisrc
            built_api = apisrc.build()
            self.checkDiff(api_file_name, self.api_path, built_api)
            built_example = apisrc.buildExample()
            example_file_name = api_file_name.replace('Api','Example')
            self.checkDiff(example_file_name, self.example_path, built_example)
            print ("isOk")

    def checkDiff(self, api_file_name, api_dir, built):
        outPath = '/tmp/'+api_file_name
        self.storeToFile(built, outPath)
        cmd = 'diff -u %s/%s %s' % (api_dir, api_file_name, outPath)
        diff = self.command(cmd)
        assert_diff_is_empty(diff.decode('utf8'), cmd)

    def storeToFile(self, data, path):
        out = open(path, 'w')
        out.write(data)
        out.close()


if __name__ == '__main__':
    t = testApiChanges()
    t.setUp()
    t.testAll()
    t.tearDown()


#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import sys
import logging
import threading

isPython3 = sys.version_info[:2] >= (3, 0)


class Logger(object):
    collected = []

    def __init__(self, name, loglevel, logfile="smartling-api-sdk-python.log"):
        logFormat = ('[%(asctime)s] %(levelname)-2s %(name)-4s %(message)s')

        logging.basicConfig(filename=logfile, filemode='a', format=logFormat, level=logging.DEBUG)
        self.sys_write = sys.stdout.write
        self.loglevel = loglevel
        name = self.addThreadName(name)
        self.logger = logging.getLogger(name)

    def addThreadName(self, name):
        threadName = threading.current_thread().name
        if 'MainThread' != threadName:
            name += "-" + threadName
        return name

    def write(self, message):
        self.sys_write(message)

        hasNewline = '\n' in message
        if message.startswith("\n"):
            message = message[1:]

        if isPython3:
            self.collected.append(message)
            if not hasNewline:
                return
            message = ''.join(self.collected)
            self.collected = []

        self.logger.log(self.loglevel, message)

    def flush(self):
        if self.collected:
            message = ''.join(self.collected)
            self.logger.info(message)



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
"""

from builder.Parameters import Code
from builder.ExampleData import TestData

testsOrder = [
    'addStringsToProject',
    'getAddStringsToProjectRequestStatus',
    'getAllSourceStringsByProject',
    'getAllTranslationsByProject',
]

imports = '''
# example of custom user-agent setup
from smartlingApiSdk.Settings import Settings
Settings.userAgent = "My Custom User Agent"

# example of custom logger settings
from smartlingApiSdk.Settings import Settings
import logging
Settings.logPath = '/tmp/python.sdk.log'
Settings.logLevel = logging.DEBUG
'''

extraInitializations = ''

testEnvironment = 'stg'

testDecorators = {
    'addStringsToProject':TestData(
        {
            'strings' : Code('''[
                {
                    "stringText": "Strings API test from python api sdk",
                    "callbackUrl": "https://test.strings.smartling.com/test",
                    "callbackMethod": "GET",
                    "instruction": "Do nothing it's a test",
                    "maxLength": 4096,
                    "format": "auto",
                },
                {
                    "stringText": "Another Strings API test from python api sdk",
                    "callbackUrl": "https://test.strings.smartling.com/test",
                    "callbackMethod": "GET",
                    "instruction": "Do nothing it's a test",
                    "maxLength": 4096,
                    "format": "auto",
                },
                {
                    "stringText": 'Service',
                    "callbackUrl": "https://test.strings.smartling.com/test",
                    "callbackMethod": "GET",
                    "instruction": "Do nothing it's a test",
                    "maxLength": 4096,
                    "format": "auto",
                },
                {
                    "stringText": 'Usability Testing',
                    "callbackUrl": "https://test.strings.smartling.com/test",
                    "callbackMethod": "GET",
                    "instruction": "Do nothing it's a test",
                    "maxLength": 4096,
                    "format": "auto",
                },
            ]'''),
            'placeholderFormat' : 'none',
            'placeholderFormatCustom' : '',
            'namespace' : '',

        },
        [],
        [
            'self.processUid = res.data.processUid',
            "self.hashcode_0 = res.data.items[0]['hashcode']",
            "self.hashcode_1 = res.data.items[1]['hashcode']",
        ],
        customTestCheck='''
assert_equal(res.data.wordCount, 18)
assert_equal(res.data.stringCount, 4)
stringTexts = [res.data.items[0]['stringText'], res.data.items[1]['stringText']]
assert_equal(True, 'Strings API test from python api sdk' in stringTexts)
assert_equal(True, 'Another Strings API test from python api sdk' in stringTexts)
'''
    ),

    'getAddStringsToProjectRequestStatus': TestData(
        {'processUid':Code('self.processUid')},
        customTestCheck='''
assert_equal(res.data.processUid, self.processUid)
assert_equal(res.data.processStatistics['requested'], 4)
assert_equal(res.data.processStatistics['errored'], 0)
'''
    ),

    'getAllSourceStringsByProject': TestData(
        {'hashcodes':Code('[self.hashcode_0,self.hashcode_1]')},
         customTestCheck='''
assert_equal(res.data.totalCount, 2)
stringTexts = [res.data.items[0]['stringText'], res.data.items[1]['stringText']]
assert_equal(True, 'Strings API test from python api sdk' in stringTexts)
assert_equal(True, 'Another Strings API test from python api sdk' in stringTexts)
'''
    ),

    'getAllTranslationsByProject': TestData(
        {
            'hashcodes':Code('[self.hashcode_0,self.hashcode_1]'),
            'targetLocaleId': 'zh-TW'
        },
        customTestCheck='''
assert_equal(res.data.totalCount, 0)
'''
    ),
}


#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
"""

from builder.Parameters import Code
from builder.ExampleData import TestData

testsOrder = [
    "getProjectsByAccount",
    "getProjectDetails",
    "addLocaleToProject",
    "copyProject",
    "getProjectCopyRequestStatus",
]

extraInitializations = '''
'''

testEnvironment = 'stg'

testDecorators = {
    'getProjectsByAccount':TestData(
        {
        },
        customTestCheck='''
assert_equal(True, res.data.totalCount > 0)
project_name = ''
for p in res.data.items:
    if p['projectId'] == self.MY_PROJECT_ID:
        project_name = p['projectName']
assert_equal('test variants', project_name)
'''
    ),

    'getProjectDetails':TestData(
        {
        },
        customTestCheck='''
assert_equal(res.data.projectId, self.MY_PROJECT_ID)
assert_equal(res.data.projectName, 'test variants')
assert_equal(res.data.accountUid, self.MY_ACCOUNT_UID)
'''
    ),

    'addLocaleToProject':TestData(
        {
            'defaultWorkflowUid': '748398939979',
            'localeId':'es-MX',
        },
        customTestCheck='''
assert_equal(res.data.projectId, self.MY_PROJECT_ID)
assert_equal(res.data.projectName, 'test variants')
assert_equal(res.data.accountUid, self.MY_ACCOUNT_UID)
locales = [l['localeId'] for l in res.data.targetLocales]
assert_equal(True, 'es-MX' in locales)
''' ),

    'copyProject':TestData(
        {
            'projectName': 'python SDK test',
            'targetLocaleIds':['es-MX', 'zh-TW'],
        },
        [],
        ['self.copy_process_uid  = res.data.processUid'],
        customTestCheck='''
assert_equal(res.code, 'ACCEPTED')
'''),

    'getProjectCopyRequestStatus':TestData(
        {
            'processUid': Code('self.copy_process_uid'),
        },
        customTestCheck='''
assert_equal(res.data.processUid, self.copy_process_uid)
assert_equal(True, res.data.processState in ['IN_PROGRESS','COMPLETED'])
'''),

}


#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

#FileApi class implementation

from .ProjectsApiV2 import ProjectsApiV2

class SmartlingProjectsApiV2(ProjectsApiV2):
    """ Wrapper class providing access to projects API commands, all methods below represent API commands.
        Each command returns tuple = (response, status_code) 
        where response is ApiResponse object and status code = HTTP response status code
        
        ApiResponse object is python object as a result of json response parsing
        ApiResponse attributes depend on response json.
        To view all attributes of response use:
        for k,v in response.items(): print k, ':' ,v
        
        Response also can be a string to provide backward compatibility with previous versions
        in case you need json response as a string use :
        api = SmartlingFileApi(userIdentifier, userSecret, projectId)
        api.response_as_string = True
        
        Some of methods may be called with optional parameters
        like `list` method may have locale optional parameter or offset parameter
        simple list:
             api.list()
        list with additional parameters:
             api.list(limit=100, offset=50)
        """

    def __init__(self, userIdentifier, userSecret, proxySettings=None, permanentHeaders={}):
        ProjectsApiV2.__init__(self, userIdentifier, userSecret, proxySettings, permanentHeaders=permanentHeaders)

    def projects(self, accountUid):
        """
        Returns a list of all projects in an account, including basic project details.
        returns (response, status_code) tuple
        http://docs.smartling.com/pages/API/v2/Projects/List-Projects/
        """
        return self.commandProjects(accountUid)

    def project_details(self, projectId):
        """
        Returns basic details on a specific Smartling project.
        returns (response, status_code) tuple
        for details see http://docs.smartling.com/pages/API/v2/Projects/Project-Details/
        """
        return self.commandProjectDetails(projectId)




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
"""

from builder.Parameters import Code
from builder.ExampleData import TestData

testsOrder = [
   'assignCustomFieldsToProject', #result is used in addJob
   'addJob',
   'addLocaleToJob',
   'addStringsToJob',
   'addFileToJob',
   'getJobFilesList',
   'getJobFileProgress',
   'authorizeJob',
   'modifyScheduleItemsForTranslationJob',
   'createCustomField',
   'updateCustomField',
   'removeFileFromJob',
   'removeStringsFromJob',
   'getJobLastCompletionDatesPerLocale',
   'findScheduleForTranslationJob',
   'removeLocaleFromJob',
   'getJobsByProject',
   'updateJob',
   'getJobProgress',
   'getJobDetails',
   'getStringsForTranslationJob',
   'findJobsByStrings',
   'searchForJob',
   'cancelJob',
   'deleteJob',
   'getProjectCustomFields',
   'getAccountCustomFields',
   'getJobsByAccount',
]

extraInitializations = '''
        # setUp code add-on #
        self.jobname = 'test_job_'+str(int(time.time()))
        self.deleteTestJobs()

    def deleteTestJobs(self):
        response,code = self.jobs_api.getJobsByProject()
        c = 0
        sz = len(response.data.items)
        for job in response.data.items:
            c += 1
            if job['jobName'].startswith('test_job_'):
                uid = job['translationJobUid']
                cres, cstatus = self.jobs_api.cancelJob(uid, 'test reason')
                res, status = self.jobs_api.deleteJob(uid)
                print (c, 'of', sz, uid, cstatus, status)

    def dateTimeStr(self, offset):
        return datetime.datetime.fromtimestamp(time.time()+offset).strftime("%Y-%m-%dT%H:%M:%SZ")
'''

jobUidCode = Code('self.test_job_uid')

testDecorators = {
'addJob':TestData(
    {
        'jobName' : Code('self.jobname'),
        'targetLocaleIds' : Code('[self.MY_LOCALE,]'),
        'description' : 'testDescription',
        'dueDate' : Code('self.dateTimeStr(3600*24*30)'),
        'referenceNumber' : 'testReferenceNumber',
        'callbackUrl' : 'https://www.callback.com/smartling/job',
        'callbackMethod': 'GET',
        'customFields' : Code('[{"fieldUid": self.fieldUid, "fieldValue": "Test Field Value"}]'),
    },
    [],
    ["self.test_job_uid = res.data.translationJobUid",]
),

'updateJob':  TestData(
    {
        'translationJobUid':Code('self.test_job_uid'),
        'jobName' : Code('"new name" + self.jobname'),
        'description' : 'new Description',
        'dueDate' : Code('self.dateTimeStr(3600*24*120)'),
        'referenceNumber' : 'new ReferenceNumber',
        'callbackUrl' : 'https://www.callback.com/smartling/new_job',
        'callbackMethod': 'POST',
        'customFields' : [],
    }
),

'findJobsByStrings' : TestData(
    {'hashcodes':Code('[]'), 'localeIds' : Code('[self.MY_LOCALE,]'),}
),

'getAccountCustomFields' : TestData(
    {'accountUid':Code('self.MY_ACCOUNT_UID')}
),

'assignCustomFieldsToProject' : TestData(
    {'accountUid':Code('self.MY_ACCOUNT_UID'),
     'CustomFieldAssignmentList': Code('[{"fieldUid":self.fieldUid},]')
    },
'''
resp, code = self.jobs_api.getAccountCustomFields(self.MY_ACCOUNT_UID)
self.fieldUid=None
for fld in resp.data.items:
    if 'python-sdk-test' == fld['fieldName']:
        self.fieldUid = fld['fieldUid']

'''.split('\n')
),

'updateCustomField' : TestData(
    {'accountUid':Code('self.MY_ACCOUNT_UID'),
     "fieldUid": Code("self.fieldUid"),
     "fieldName": "python-sdk-test",
     "enabled": True,
     "required": False,
     "searchable": True,
     "displayToTranslators": True,
     "options": [],
     "defaultValue": "New default field value",
     "description": "New custom field example"
     },
),


'createCustomField' : TestData(
    {'accountUid':Code('self.MY_ACCOUNT_UID'),
      "type": "SHORT_TEXT",
      "fieldName": "python-sdk-test",
      "enabled": True,
      "required": False,
      "searchable": True,
      "displayToTranslators": True,
      "options": [],
      "defaultValue": "default field value",
      "description": "Custom field example"

    },
    ['self.jobs_api.httpClient.ignore_errors=True'],
    ['self.jobs_api.httpClient.ignore_errors=False'],
    customTestCheck='''
if 400 == status:
    assert_equal(True, 'Field name must be unique within account' in str(res))
else:
    assert_equal(True, status in [200,202])
    assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKED])
''',
    isApiV2Response= False,
),

'getJobProgress' :                     TestData({'translationJobUid':jobUidCode}),
'getJobDetails' :                      TestData({'translationJobUid':jobUidCode}),
'deleteJob' :                          TestData({'translationJobUid':jobUidCode}),
'getStringsForTranslationJob' :        TestData({'translationJobUid':jobUidCode}),
'getJobLastCompletionDatesPerLocale' : TestData({'translationJobUid':jobUidCode}),
'findScheduleForTranslationJob' :      TestData({'translationJobUid':jobUidCode}),
'getJobFilesList' :                    TestData({'translationJobUid':jobUidCode}),

'authorizeJob' : TestData({
    'localeWorkflows': Code(' [ { "targetLocaleId": "zh-TW", "workflowUid": "748398939979" } ]'),
    'translationJobUid': jobUidCode,
}
),

'modifyScheduleItemsForTranslationJob' : TestData({
    'schedules': Code(' [ { "targetLocaleId": "zh-TW", "workflowStepUid": "7f6126eff318", "dueDate": self.dateTimeStr(3600*24*30)} ]'),
    'translationJobUid': jobUidCode,
}
),

'addStringsToJob' : TestData({
    'hashcodes' : Code('["e1159037badca0a2a618f62c50eff1bb", ] # use your string hashcodes list here'),
    'moveEnabled': Code('False'),
    'targetLocaleIds' : Code('[self.MY_LOCALE,]'),
    'translationJobUid': jobUidCode,
}, [], [
    'assert_equal(0, res.data.failCount, "addStringsToJob will fail if string was already in other job")',
]
),

'removeStringsFromJob' : TestData({
    'hashcodes' : Code('["e1159037badca0a2a618f62c50eff1bb", ] # use your string hashcodes list here'),
    'localeIds' : Code('[self.MY_LOCALE,]'),
    'translationJobUid': jobUidCode,
}
),

'searchForJob' : TestData({
    'fileUris':Code('[]'),
    'hashcodes':Code('[]'),
    'translationJobUids':Code('[self.test_job_uid]'),
}),


'cancelJob' : TestData(
    {'translationJobUid':jobUidCode, 'reason':'test reason'}
),

'getJobsByProject' : TestData({'jobName':Code('self.jobname')}),

'addLocaleToJob' : TestData({'translationJobUid':jobUidCode,
                                        'targetLocaleId' : Code('"zh-TW" #use your other locale here'),
                                        'syncContent' : Code('True')
                                        }),

'removeLocaleFromJob' : TestData({'translationJobUid':jobUidCode,
                                        'targetLocaleId' : Code('"zh-TW" #use already added locale here'),
                                        }),

'addFileToJob' : TestData({'translationJobUid':jobUidCode,
                                      'targetLocaleIds' : Code('[self.MY_LOCALE,]'),
                                      'fileUri' : Code('"test_import.xml_2.2.4_1629202583.584802" #use your actual file uri uploaded earielr to Smartling')
                                      }),

'getJobFileProgress' : TestData({'translationJobUid':jobUidCode,
                                      'fileUri' : Code('"test_import.xml_2.2.4_1629202583.584802" #use your actual file uri uploaded earielr to Smartling')
                                      }),
'removeFileFromJob' : TestData({'translationJobUid':jobUidCode,
                                      'fileUri' : Code('"test_import.xml_2.2.4_1629202583.584802" #use your actual file uri uploaded earielr to Smartling')
                                      }),
}



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
import time, datetime

sys.path += [os.path.abspath('../'), os.path.abspath('../../')]  # allow to import ../smartlingApiSdk.api

import smartlingApiSdk
from smartlingApiSdk.api.StringsApi import StringsApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

isPython3 =  sys.version_info[:2] >= (3,0)

# example of custom user-agent setup
from smartlingApiSdk.Settings import Settings
Settings.userAgent = "My Custom User Agent"

# example of custom logger settings
from smartlingApiSdk.Settings import Settings
import logging
Settings.logPath = '/tmp/python.sdk.log'
Settings.logLevel = logging.DEBUG

def assert_equal(a,b, comment=''):
    if a != b :
        err = "Assertion Failed: '%s' != '%s' %s" % (a,b, comment)
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class testStringsApi(object):

    CODE_SUCCESS_TOKEN = 'SUCCESS'
    ACCEPTED_TOKEN = 'ACCEPTED'

    def tearDown(self):
        print("tearDown", "OK")

    def setUp(self):
        credentials = Credentials('stg') #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
        self.MY_LOCALE = credentials.MY_LOCALE

        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None

        self.strings_api = StringsApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')

        print("setUp", "OK", "\n")

    def checkAddStringsToProject(self):
        """
            method  :  POST
            api url :  /strings-api/v2/projects/{projectId}
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d "$smartlingStringJSON" https://api.smartling.com/strings-api/v2/projects/$smartlingProjectId
            Responses:
                200 : OK
                202 : ACCEPTED
            details :  https://api-reference.smartling.com/#operation/addStringsToProject
        """
        strings=[
                {
                    "stringText": "Strings API test from python api sdk",
                    "callbackUrl": "https://test.strings.smartling.com/test",
                    "callbackMethod": "GET",
                    "instruction": "Do nothing it's a test",
                    "maxLength": 4096,
                    "format": "auto",
                },
                {
                    "stringText": "Another Strings API test from python api sdk",
                    "callbackUrl": "https://test.strings.smartling.com/test",
                    "callbackMethod": "GET",
                    "instruction": "Do nothing it's a test",
                    "maxLength": 4096,
                    "format": "auto",
                },
                {
                    "stringText": 'Service',
                    "callbackUrl": "https://test.strings.smartling.com/test",
                    "callbackMethod": "GET",
                    "instruction": "Do nothing it's a test",
                    "maxLength": 4096,
                    "format": "auto",
                },
                {
                    "stringText": 'Usability Testing',
                    "callbackUrl": "https://test.strings.smartling.com/test",
                    "callbackMethod": "GET",
                    "instruction": "Do nothing it's a test",
                    "maxLength": 4096,
                    "format": "auto",
                },
            ]
        placeholderFormat='none'
        placeholderFormatCustom=''
        namespace=''
        res, status = self.strings_api.addStringsToProject(strings=strings, placeholderFormat=placeholderFormat, placeholderFormatCustom=placeholderFormatCustom, namespace=namespace)


        assert_equal(res.data.wordCount, 18)
        assert_equal(res.data.stringCount, 4)
        stringTexts = [res.data.items[0]['stringText'], res.data.items[1]['stringText']]
        assert_equal(True, 'Strings API test from python api sdk' in stringTexts)
        assert_equal(True, 'Another Strings API test from python api sdk' in stringTexts)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('addStringsToProject', 'OK')
        self.processUid = res.data.processUid
        self.hashcode_0 = res.data.items[0]['hashcode']
        self.hashcode_1 = res.data.items[1]['hashcode']


    def checkGetAddStringsToProjectRequestStatus(self):
        """
            method  :  GET
            api url :  /strings-api/v2/projects/{projectId}/processes/{processUid}
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -G https://api.smartling.com/strings-api/v2/projects/$smartlingProjectId/processes/$processUid
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getAddStringsToProjectRequestStatus
        """
        processUid=self.processUid
        res, status = self.strings_api.getAddStringsToProjectRequestStatus(processUid=processUid)


        assert_equal(res.data.processUid, self.processUid)
        assert_equal(res.data.processStatistics['requested'], 4)
        assert_equal(res.data.processStatistics['errored'], 0)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getAddStringsToProjectRequestStatus', 'OK')


    def checkGetAllSourceStringsByProject(self):
        """
            method  :  POST
            api url :  /strings-api/v2/projects/{projectId}/source-strings
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -G -d "fileUri=$smartlingFileUri" https://api.smartling.com/strings-api/v2/projects/$smartlingProjectId/source-strings
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getAllSourceStringsByProject
        """
        hashcodes=[self.hashcode_0,self.hashcode_1]
        res, status = self.strings_api.getAllSourceStringsByProject(hashcodes=hashcodes)


        assert_equal(res.data.totalCount, 2)
        stringTexts = [res.data.items[0]['stringText'], res.data.items[1]['stringText']]
        assert_equal(True, 'Strings API test from python api sdk' in stringTexts)
        assert_equal(True, 'Another Strings API test from python api sdk' in stringTexts)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getAllSourceStringsByProject', 'OK')


    def checkGetAllTranslationsByProject(self):
        """
            method  :  POST
            api url :  /strings-api/v2/projects/{projectId}/translations
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -G https://api.smartling.com/strings-api/v2/projects/$smartlingProjectId/translations
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getAllTranslationsByProject
        """
        targetLocaleId='zh-TW'
        hashcodes=[self.hashcode_0,self.hashcode_1]
        res, status = self.strings_api.getAllTranslationsByProject(targetLocaleId=targetLocaleId, hashcodes=hashcodes)


        assert_equal(res.data.totalCount, 0)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getAllTranslationsByProject', 'OK')



def example():
    t = testStringsApi()
    t.setUp()
    t.checkAddStringsToProject()
    t.checkGetAddStringsToProjectRequestStatus()
    t.checkGetAllSourceStringsByProject()
    t.checkGetAllTranslationsByProject()
    t.tearDown()

if __name__ == '__main__':
    example()



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
"""

from builder.Parameters import Code
from builder.ExampleData import TestData

testsOrder = [
    'createJobBatchV2',
    'getJobBatchesListV2',
    'getJobBatchStatusV2',
    'uploadFileToJobBatchV2',
    'processBatchActionV2',
]

extraInitializations = '''
'''

testEnvironment = 'stg'

testDecorators = {
'createJobBatchV2':TestData(
    {
        'authorize' : False,
        'translationJobUid' : Code('"c4e4b14773bd"  #use real batch job here'),
        'fileUris': Code('[self.file_uri, "file_to_cancel_later"]'),
        'localeWorkflows': Code(' [ { "targetLocaleId": "zh-TW", "workflowUid": "748398939979" } ]'),
},
    ['self.file_uri = "java.properties.jb2.%d" % time.time()',],
    ['self.batch_uid = res.data.batchUid']
),

'getJobBatchStatusV2': TestData({'batchUid':Code('self.batch_uid')}),

'processBatchActionV2': TestData({
    'batchUid': Code('self.batch_uid'),
    'action' : 'CANCEL_FILE',
    'fileUri': 'file_to_cancel_later',
    'reason' : 'test reason'
}),

'uploadFileToJobBatchV2': TestData({
    'batchUid': Code('self.batch_uid'),
    'file' : Code('textData'),
    'fileUri': Code('self.file_uri'),
    'fileType':'javaProperties',
    'authorize':False,
    'localeIdsToAuthorize':Code('["zh-TW",]'),
    'callbackUrl' : 'https://www.callback.com/smartling/python/sdk/jb2.test',
},
    ["textData = open(smartlingApiSdk.__path__[0]+'/resources/java.properties', 'rb').read().decode('utf-8', 'ignore')"]
),



}



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
import time, datetime

sys.path += [os.path.abspath('../'), os.path.abspath('../../')]  # allow to import ../smartlingApiSdk.api

import smartlingApiSdk
from smartlingApiSdk.api.FilesApi import FilesApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

isPython3 =  sys.version_info[:2] >= (3,0)

from smartlingApiSdk.Constants import FileTypes
from datetime import date
import zipfile
if isPython3:
    import io
else:
    import StringIO

if isPython3:
    newline = b"\n"
else:
    newline = "\n"

def assert_equal(a,b, comment=''):
    if a != b :
        err = "Assertion Failed: '%s' != '%s' %s" % (a,b, comment)
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class testFilesApi(object):

    CODE_SUCCESS_TOKEN = 'SUCCESS'
    ACCEPTED_TOKEN = 'ACCEPTED'

    def tearDown(self):
        print("tearDown", "OK")

    def setUp(self):
        credentials = Credentials('stg') #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
        self.MY_LOCALE = credentials.MY_LOCALE

        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None

        self.files_api = FilesApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')

        print("setUp", "OK", "\n")

        self.extraInitializations()

    def extraInitializations(self):
        self.FILE_NAME = "java.properties"
        self.FILE_NAME_16 = "javaUTF16.properties"
        self.FILE_TYPE = "javaProperties"
        self.FILE_TYPE_CSV = "csv"
        self.FILE_PATH = smartlingApiSdk.__path__[0]+"/resources/"
        self.FILE_NAME_NEW = "java.properties.renamed"
        self.FILE_NAME_NEW_16 = "javaUTF16.properties.renamed"
        self.FILE_NAME_CSV = "test.csv"
    
        self.FILE_NAME_IMPORT_ORIG = "test_import.xml"
        self.FILE_NAME_IMPORT_TRANSLATED = "test_import_es.xml"
        self.FILE_TYPE_IMPORT = "android"

        self.CALLBACK_URL = "http://google.com/?q=hello"

        unique_suffix = "_" + repr(time.time())
        self.uri = self.FILE_NAME + unique_suffix 
        self.uri16 = self.FILE_NAME_16 + unique_suffix 
        res, status = self.files_api.uploadSourceFile(self.FILE_PATH + self.FILE_NAME_16, fileType=self.FILE_TYPE, fileUri = self.uri16, localeIdsToAuthorize = [self.MY_LOCALE] )
        
        self.uri_to_rename = self.FILE_NAME_NEW + unique_suffix
        self.uri_import = self.FILE_NAME_IMPORT_ORIG + unique_suffix

        self.file_json = "simple.json"
        self.uri_json = unique_suffix + self.file_json
        res, status = self.files_api.uploadSourceFile(self.FILE_PATH + self.file_json, fileType="json", fileUri=self.uri_json, localeIdsToAuthorize = [self.MY_LOCALE] )

    def getZipFile(self, res):
        if isPython3:
            return zipfile.ZipFile(io.BytesIO(res))
        else:
            return zipfile.ZipFile(StringIO.StringIO(res))

    def checkUploadSourceFile(self):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/file
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -F "file=@$uploadFilePath;type=text/plain" -F "fileUri=$uploadFileSmartlingUri" -F "fileType=$uploadFileSmartlingType" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file"
            Responses:
                200 : OK
                202 : ACCEPTED
                423 : The requested file is currently being processed by another operation. The file will be unlocked after the operation completes.
            details :  https://api-reference.smartling.com/#operation/uploadSourceFile
        """
        file=self.FILE_PATH + self.FILE_NAME
        fileUri=self.uri
        fileType=self.FILE_TYPE
        localeIdsToAuthorize=[self.MY_LOCALE]
        res, status = self.files_api.uploadSourceFile(file=file, fileUri=fileUri, fileType=fileType, localeIdsToAuthorize=localeIdsToAuthorize)


        assert_equal(res.data.wordCount, 6)
        assert_equal(res.data.stringCount, 6)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('uploadSourceFile', 'OK')


    def checkDownloadSourceFile(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/file
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -G --data-urlencode "fileUri=$smartlingFileUri" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/downloadSourceFile
        """
        fileUri=self.uri_json
        res, status = self.files_api.downloadSourceFile(fileUri=fileUri)


        orig = open(self.FILE_PATH + self.file_json , "rb").read()
        assert_equal(res, orig)

        print('downloadSourceFile', 'OK')


    def checkGetFileTranslationStatusAllLocales(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/file/status
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getFileTranslationStatusAllLocales
        """
        fileUri=self.uri
        res, status = self.files_api.getFileTranslationStatusAllLocales(fileUri=fileUri)


        assert_equal(res.data.fileUri, self.uri)
        assert_equal(True, len(res.data.items) > 0)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getFileTranslationStatusAllLocales', 'OK')


    def checkGetFileTranslationStatusSingleLocale(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file/status
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getFileTranslationStatusSingleLocale
        """
        localeId=self.MY_LOCALE
        fileUri=self.uri
        res, status = self.files_api.getFileTranslationStatusSingleLocale(localeId=localeId, fileUri=fileUri)


        assert_equal(res.data.fileUri, self.uri)
        assert_equal(res.data.fileType, self.FILE_TYPE)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getFileTranslationStatusSingleLocale', 'OK')


    def checkDownloadTranslatedFileSingleLocale(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -o $smartlingLocaleId$smartlingFileUri -G --data-urlencode "fileUri=$smartlingFileUri" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/locales/$smartlingLocaleId/file"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/downloadTranslatedFileSingleLocale
        """
        localeId=self.MY_LOCALE
        fileUri=self.uri
        res, status = self.files_api.downloadTranslatedFileSingleLocale(localeId=localeId, fileUri=fileUri)


        resp_lines_count = len(res.decode('utf-8').split('\n'))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME, "rb").read().decode('utf-8').split('\n') )
        assert_equal(resp_lines_count, file_lines_count)

        print('downloadTranslatedFileSingleLocale', 'OK')


    def checkDownloadTranslatedFilesAllLocales(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/locales/all/file/zip
            as curl :  curl -X GET -H "Authorization: Bearer $smartlingToken" 'https://api.smartling.com/files-api/v2/projects/{projectId}/locales/all/file/zip?fileUri=yourfile.json&retrievalType=published'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/downloadTranslatedFilesAllLocales
        """
        fileUri=self.uri
        res, status = self.files_api.downloadTranslatedFilesAllLocales(fileUri=fileUri)


        zfile = self.getZipFile(res)
        names = zfile.namelist()
        assert_equal(True, self.MY_LOCALE+'/'+self.uri in names)

        print('downloadTranslatedFilesAllLocales', 'OK')


    def checkDownloadMultipleTranslatedFiles(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/files/zip
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/downloadMultipleTranslatedFiles
        """
        fileUris=[self.uri,self.uri16]
        localeIds=[self.MY_LOCALE, 'zh-TW']
        res, status = self.files_api.downloadMultipleTranslatedFiles(fileUris=fileUris, localeIds=localeIds)


        zfile = self.getZipFile(res)
        names = zfile.namelist()
        assert_equal(True, self.MY_LOCALE+'/'+self.uri in names)
        assert_equal(True, self.MY_LOCALE+'/'+self.uri16 in names)
        assert_equal(True, 'zh-TW'+'/'+self.uri in names)
        assert_equal(True, 'zh-TW'+'/'+self.uri16 in names)

        print('downloadMultipleTranslatedFiles', 'OK')


    def checkGetRecentlyUploadedSourceFilesList(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/files/list
            as curl :  curl -H "Authorization: Bearer $smartlingToken" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/files/list?fileTypes[]=json&uriMask=strings"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getRecentlyUploadedSourceFilesList
        """
        fileTypes=[FileTypes.android, FileTypes.javaProperties]
        res, status = self.files_api.getRecentlyUploadedSourceFilesList(fileTypes=fileTypes)


        uris = [x['fileUri'] for x in res.data.items]
        assert_equal(True, self.uri in uris)
        assert_equal(True, self.uri16 in uris)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getRecentlyUploadedSourceFilesList', 'OK')


    def checkGetFileTypesList(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/file-types
            as curl :  curl -H "Authorization: Bearer $smartlingToken" "https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file-types"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getFileTypesList
        """
        res, status = self.files_api.getFileTypesList()


        assert_equal(True, "javaProperties" in res.data.items)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getFileTypesList', 'OK')


    def checkRenameUploadedSourceFile(self):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/file/rename
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -F "fileUri=filename.properties" -F "newFileUri=filename2.properties" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file/rename'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/renameUploadedSourceFile
        """
        fileUri=self.uri
        newFileUri=self.uri_to_rename
        res, status = self.files_api.renameUploadedSourceFile(fileUri=fileUri, newFileUri=newFileUri)


        res, status = self.files_api.renameUploadedSourceFile(self.uri_to_rename, self.uri) #rename it back so in the end it could be removed

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('renameUploadedSourceFile', 'OK')


    def checkGetTranslatedFileLastModifiedDateSingleLocale(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file/last-modified
            as curl :  curl -X GET -H "Authorization: Bearer $smartlingToken" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/locales/$smartlingLocaleId/file/last-modified?fileUri=filename.properties'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getTranslatedFileLastModifiedDateSingleLocale
        """
        localeId=self.MY_LOCALE
        fileUri=self.uri
        res, status = self.files_api.getTranslatedFileLastModifiedDateSingleLocale(localeId=localeId, fileUri=fileUri)


        lm_date = res.data.lastModified[:10]
        assert_equal(lm_date,  date.today().isoformat())

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getTranslatedFileLastModifiedDateSingleLocale', 'OK')


    def checkGetTranslatedFileLastModifiedDateAllLocales(self):
        """
            method  :  GET
            api url :  /files-api/v2/projects/{projectId}/file/last-modified
            as curl :  curl -X GET -H "Authorization: Bearer $smartlingToken" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file/last-modified?fileUri=filename.properties'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getTranslatedFileLastModifiedDateAllLocales
        """
        fileUri=self.uri
        res, status = self.files_api.getTranslatedFileLastModifiedDateAllLocales(fileUri=fileUri)


        assert_equal(True, len(res.data.items) > 0)
        for l in res.data.items:
            if l['localeId'] == self.MY_LOCALE:
                lm_date = l['lastModified'][:10]
                assert_equal(lm_date,  date.today().isoformat())

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getTranslatedFileLastModifiedDateAllLocales', 'OK')


    def checkImportFileTranslations(self):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file/import
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -F "file=@filename.properties" -F "fileUri=filename.properties" -F "fileType=javaProperties" -F "translationState=PUBLISHED" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/locales/$smartlingLocaleId/file/import'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/importFileTranslations
        """
        res, status = self.files_api.uploadSourceFile(self.FILE_PATH + self.FILE_NAME_IMPORT_ORIG, fileType = self.FILE_TYPE_IMPORT , fileUri=self.uri_import)
        localeId=self.MY_LOCALE
        file=self.FILE_PATH + self.FILE_NAME_IMPORT_TRANSLATED
        fileUri=self.uri_import
        fileType=self.FILE_TYPE_IMPORT
        translationState='PUBLISHED'
        res, status = self.files_api.importFileTranslations(localeId=localeId, file=file, fileUri=fileUri, fileType=fileType, translationState=translationState)



        assert_equal(res.data.wordCount, 2)
        assert_equal(res.data.stringCount, 2)
        assert_equal(res.data.translationImportErrors, [])

        res, status = self.files_api.deleteUploadedSourceFile(self.uri_import)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)


        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('importFileTranslations', 'OK')


    def checkExportFileTranslations(self):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/locales/{localeId}/file/get-translations
            as curl :  curl -H "Authorization: Bearer $smartlingToken" -F "file=@filename.properties" -F 'fileUri=filename.properties' 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/locales/$smartlingLocaleId/file/get-translations'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/exportFileTranslations
        """
        localeId=self.MY_LOCALE
        file=self.FILE_PATH+self.FILE_NAME
        fileUri=self.uri
        res, status = self.files_api.exportFileTranslations(localeId=localeId, file=file, fileUri=fileUri)


        assert_equal(True, res is not None)
        resp_lines_count = len(res.split(newline))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME, "rb").readlines() )
        assert_equal(resp_lines_count, file_lines_count)

        print('exportFileTranslations', 'OK')


    def checkGetRecentlyPublishedFilesList(self):
        """
            method  :  GET
            api url :  /published-files-api/v2/projects/{projectId}/files/list/recently-published
            as curl :  curl -H "Authorization: Bearer $smartlingToken" 'https://api.smartling.com/published-files-api/v2/projects/$smartlingProjectId/files/list/recently-published?publishedAfter=2019-11-21T11:51:17Z&fileUris[]=files/example1.json&localeIds[]=fr-CA&limit=10&offset=100'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getRecentlyPublishedFilesList
        """
        publishedAfter=datetime.datetime.fromtimestamp(time.time()-10*24*2600).strftime("%Y-%m-%d")
        localeIds=[self.MY_LOCALE]
        res, status = self.files_api.getRecentlyPublishedFilesList(publishedAfter=publishedAfter, localeIds=localeIds)


        assert_equal(True, hasattr(res.data, 'items'))

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getRecentlyPublishedFilesList', 'OK')


    def checkDeleteUploadedSourceFile(self):
        """
            method  :  POST
            api url :  /files-api/v2/projects/{projectId}/file/delete
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -F "fileUri=filename.properties" 'https://api.smartling.com/files-api/v2/projects/$smartlingProjectId/file/delete'
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/deleteUploadedSourceFile
        """
        fileUri=self.uri
        res, status = self.files_api.deleteUploadedSourceFile(fileUri=fileUri)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('deleteUploadedSourceFile', 'OK')



    def test_all(self):
        t = self
        t.checkUploadSourceFile()
        t.checkDownloadSourceFile()
        t.checkGetFileTranslationStatusAllLocales()
        t.checkGetFileTranslationStatusSingleLocale()
        t.checkDownloadTranslatedFileSingleLocale()
        t.checkDownloadTranslatedFilesAllLocales()
        t.checkDownloadMultipleTranslatedFiles()
        t.checkGetRecentlyUploadedSourceFilesList()
        t.checkGetFileTypesList()
        t.checkRenameUploadedSourceFile()
        t.checkGetTranslatedFileLastModifiedDateSingleLocale()
        t.checkGetTranslatedFileLastModifiedDateAllLocales()
        t.checkImportFileTranslations()
        t.checkExportFileTranslations()
        t.checkGetRecentlyPublishedFilesList()
        t.checkDeleteUploadedSourceFile()



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

# FileApi class implementation

from .AuthClient import AuthClient
from .Constants import FileTypes
from .Constants import Params
from .FileApiBase import FileApiBase
from .SmartlingDirective import SmartlingDirective
from .UrlV2Helper import UrlV2Helper
from .version import version


class ApiV2(FileApiBase):
    """ Api v2 basic functionality """
    hostProd = 'api.smartling.com'
    hostStg = 'api.stg.smartling.net'
    clientUid = "{\"client\":\"smartling-api-sdk-python\",\"version\":\"%s\"}" % version

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        self.host = self.hostProd
        self.userIdentifier = userIdentifier
        if 'stg'==env:
            self.host = self.hostStg
        FileApiBase.__init__(self, self.host, userIdentifier, userSecret, proxySettings, permanentHeaders=permanentHeaders)
        self.authClient = AuthClient(self.host, userIdentifier, userSecret, proxySettings)
        self.urlHelper = UrlV2Helper(projectId)

    def addAuth(self, params):
        token = self.authClient.getToken()
        if token is None:
            raise Exception("Error getting token, userIdentifier:%s" % (self.userIdentifier))
        return {"Authorization": "Bearer " + token}

    def validateFileTypes(self, kw):
        fileTypes = kw.get("fileTypes", [])
        if type(fileTypes) != type([]) and type(fileTypes) != type(()):
            fileTypes = [fileTypes]
        for t in fileTypes:
            if not getattr(FileTypes, t, None):
                unsupported = "\nUnsupported file type:%s\n" % t
                raise Exception(unsupported)

    def checkRetrievalType(self, kw):
        if Params.RETRIEVAL_TYPE in kw and not kw[Params.RETRIEVAL_TYPE] in Params.allowedRetrievalTypes:
            Exception("Not allowed value `%s` for parameter:%s try one of %s" % (kw[Params.RETRIEVAL_TYPE],
                                                                                 Params.RETRIEVAL_TYPE,
                                                                                 Params.allowedRetrievalTypes))

    def processDirectives(self, params, directives):
        for name, value in list(directives.items()):
            params[SmartlingDirective.SL_PREFIX + name] = value

    def addLibIdDirective(self, params):
        name = "client_lib_id"
        params[SmartlingDirective.SL_PREFIX + name] = self.clientUid



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import sys

isPython3 =  sys.version_info[:2] >= (3,0)

if isPython3:
    import email.generator as mimetools
    import urllib.request as urllib2
    from urllib.parse import urlencode
else:
    import mimetools
    import urllib2
    from urllib import urlencode

import mimetypes
import io

class MultipartPostHandler(urllib2.BaseHandler):
    """ handler for multipart HTTP POST, helper object to provide POST functionality """

    handler_order = urllib2.HTTPHandler.handler_order - 10  # needs to run first
    # Controls how sequences are uncoded. If true, elements may be given multiple values by
    #  assigning a sequence.
    doseq = 1

    def ifFileInstance(self, value):
        if isPython3:
            return isinstance(value, io.IOBase) or type(value) == io.StringIO
        else:
            return type(value) == file or type(value) == io.StringIO

    def http_request(self, request, forceMultipart = False):
        if isPython3:
            data = request.data
        else:
            data = request.get_data()
            try: data = data.encode('utf-8', 'ignore')
            except: pass
        if data is not None and type(data) != str and type(data) != bytes:
            files = []
            vars = []
            try:
                for(key, value) in list(data.items()):
                    if self.ifFileInstance(value):
                        files.append((key, value))
                    else:
                        vars.append((key, value))
            except TypeError:
                systype, value, traceback = sys.exc_info()
                raise TypeError("not a valid non-string sequence or mapping object")(traceback)

            if (not forceMultipart) and len(files) == 0:
                data = urlencode(vars, self.doseq)
            else:
                boundary, data = self.multipartEncode(vars, files)
                contenttype = 'multipart/form-data; boundary=%s' % boundary

                if(request.has_header('Content-Type')
                   and request.get_header('Content-Type').find('multipart/form-data') != 0):
                    print("Replacing %s with %s" % (request.get_header('content-type'), 'multipart/form-data'))
                request.add_unredirected_header('Content-Type', contenttype)
                request.headers["Content-type"] = contenttype

            if isPython3:
                request.data = data
            else:
                request.add_data(data)
        return request

    def multipartEncode(self, vars, files):
        boundary = self.createBoundary()

        buffer = ''
        for(key, value) in vars:
            buffer += '--%s\r\n' % boundary
            buffer += 'Content-Disposition: form-data; name="%s"' % key
            buffer += '\r\n\r\n' + value + '\r\n'
        for(key, fd) in files:
            filename = fd.name.split('/')[-1]
            contenttype = mimetypes.guess_type(filename)[0] or 'application/octet-stream'
            buffer += '--%s\r\n' % boundary
            buffer += 'Content-Disposition: form-data; name="%s"; filename="%s"\r\n' % (key, filename)
            buffer += 'Content-Type: %s\r\n' % contenttype
            fd.seek(0)
            if isPython3:
                buffer = buffer.encode() + b'\r\n' + fd.read().encode() + b'\r\n'
            else:
                buffer += '\r\n' + fd.read() + '\r\n'

        if isPython3:
            if str == type(buffer):
                buffer = buffer.encode()
            buffer += b'--%b--\r\n\r\n' % boundary.encode()
        else:
            buffer += '--%s--\r\n\r\n' % boundary
        return boundary, buffer

    def createBoundary(self):
        if isPython3:
            boundary = mimetools._make_boundary()
            boundary = boundary.replace("=", "-")
        else:
            boundary = mimetools.choose_boundary()
        return boundary

    https_request = http_request



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

#FileApi V1 class implementation

from .Constants import Uri, Params, ReqMethod
from .FileApiBase import FileApiBase

class ObsoleteApiV1(FileApiBase):
    """ Api v1 basic functionality, is obsolete, new API calls are missing here, please use ApiV2 """

    def commandUpload(self, uploadData):
        params = {
                    Params.FILE_URI: uploadData.uri or uploadData.name,
                    Params.FILE_TYPE: uploadData.type,
                    Params.FILE_PATH: uploadData.path + uploadData.name
                  }
        if (uploadData.approveContent):
            params[Params.APPROVED] = uploadData.approveContent

        if (uploadData.callbackUrl):
            params[Params.CALLBACK_URL] = uploadData.callbackUrl

        if (uploadData.directives):
            for index, directive in enumerate(uploadData.directives):
                params[directive.SL_PREFIX + directive.name] = directive.value
                
        if (uploadData.localesToApprove):
            for index, locale in enumerate(uploadData.localesToApprove):
                params['{0}[{1}]'.format(Params.LOCALES_TO_APPROVE, index)] = locale

        return self.uploadMultipart(Uri.UPLOAD, params)

    def commandList(self, **kw):
        return self.command(ReqMethod.POST, Uri.LIST, kw)

    def commandLastModified(self, fileUri, locale=None, **kw):
        kw[Params.FILE_URI] = fileUri
        if locale is not None:
            kw[Params.LOCALE] = locale
        return self.command(ReqMethod.GET, Uri.LAST_MODIFIED, kw)
        
    def commandGet(self, fileUri, locale, **kw):
        kw[Params.FILE_URI] = fileUri
        kw[Params.LOCALE] = locale
        if Params.RETRIEVAL_TYPE in kw and not kw[Params.RETRIEVAL_TYPE] in Params.allowedRetrievalTypes:
            raise "Not allowed value `%s` for parameter:%s try one of %s" % (kw[Params.RETRIEVAL_TYPE],
                                                                             Params.RETRIEVAL_TYPE,
                                                                             Params.allowedRetrievalTypes)

        resp, code, headers = self.getResponseAndStatus(ReqMethod.POST, Uri.GET, kw)
        return resp, code

    def commandDelete(self, fileUri, **kw):
        kw[Params.FILE_URI] = fileUri

        return self.command(ReqMethod.POST, Uri.DELETE, kw)
        
    def commandImport(self, uploadData, locale, **kw):
        kw[Params.FILE_URI]  = uploadData.uri
        kw[Params.FILE_TYPE] = uploadData.type
        kw[Params.FILE_PATH] = uploadData.path + uploadData.name
        kw["file"] = uploadData.path + uploadData.name + ";type=text/plain"
        kw[Params.LOCALE] = locale

        return self.uploadMultipart(Uri.IMPORT, kw)

    def commandStatus(self, fileUri, locale, **kw):
        kw[Params.FILE_URI] = fileUri
        kw[Params.LOCALE] = locale

        return self.command(ReqMethod.POST, Uri.STATUS, kw)

    def commandRename(self, fileUri, newUri, **kw):
        kw[Params.FILE_URI] = fileUri
        kw[Params.FILE_URI_NEW] = newUri

        return self.command(ReqMethod.POST, Uri.RENAME, kw)




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
import time, datetime

sys.path += [os.path.abspath('../'), os.path.abspath('../../')]  # allow to import ../smartlingApiSdk.api

import smartlingApiSdk
from smartlingApiSdk.api.JobBatchesV2Api import JobBatchesV2Api
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

isPython3 =  sys.version_info[:2] >= (3,0)

def assert_equal(a,b, comment=''):
    if a != b :
        err = "Assertion Failed: '%s' != '%s' %s" % (a,b, comment)
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class testJobBatchesV2Api(object):

    CODE_SUCCESS_TOKEN = 'SUCCESS'
    ACCEPTED_TOKEN = 'ACCEPTED'

    def tearDown(self):
        print("tearDown", "OK")

    def setUp(self):
        credentials = Credentials('stg') #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
        self.MY_LOCALE = credentials.MY_LOCALE

        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None

        self.job_batches_v2_api = JobBatchesV2Api(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')

        print("setUp", "OK", "\n")


    def checkCreateJobBatchV2(self):
        """
            method  :  POST
            api url :  /job-batches-api/v2/projects/{projectId}/batches
            as curl :  curl -X POST "https://api.smartling.com/job-batches-api/v2/projects/$smartlingProjectId/batches" -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d '{"translationJobUid": "$translationJobUid", "authorize": true, "fileUris": ["example.json", "test.xml"]}'
            Responses:
                200 : OK
                404 : provided translationJobUid is not found in the TMS
            details :  https://api-reference.smartling.com/#operation/createJobBatchV2
        """
        self.file_uri = "java.properties.jb2.%d" % time.time()
        authorize=False
        translationJobUid="c4e4b14773bd"  #use real batch job here
        fileUris=[self.file_uri, "file_to_cancel_later"]
        localeWorkflows= [ { "targetLocaleId": "zh-TW", "workflowUid": "748398939979" } ]
        res, status = self.job_batches_v2_api.createJobBatchV2(authorize=authorize, translationJobUid=translationJobUid, fileUris=fileUris, localeWorkflows=localeWorkflows)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('createJobBatchV2', 'OK')
        self.batch_uid = res.data.batchUid


    def checkGetJobBatchesListV2(self):
        """
            method  :  GET
            api url :  /job-batches-api/v2/projects/{projectId}/batches
            as curl :  curl -X GET \'https://api.smartling.com/job-batches-api/v2/projects/$smartlingProjectId/batches?translationJobUid={translationJobUid}&status={status}&sortBy=createdDate&orderBy=desc&offset=0&limit=20' \-H "Authorization: Bearer $smartlingToken"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobBatchesListV2
        """
        res, status = self.job_batches_v2_api.getJobBatchesListV2()

        print('getJobBatchesListV2', 'OK')


    def checkGetJobBatchStatusV2(self):
        """
            method  :  GET
            api url :  /job-batches-api/v2/projects/{projectId}/batches/{batchUid}
            Responses:
                200 : OK
                404 : Batch provided in path is not found
            details :  https://api-reference.smartling.com/#operation/getJobBatchStatusV2
        """
        batchUid=self.batch_uid
        res, status = self.job_batches_v2_api.getJobBatchStatusV2(batchUid=batchUid)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getJobBatchStatusV2', 'OK')


    def checkUploadFileToJobBatchV2(self):
        """
            method  :  POST
            api url :  /job-batches-api/v2/projects/{projectId}/batches/{batchUid}/file
            as curl :  curl -X POST \'https://api.smartling.com/job-batches-api/v2/projects/$smartlingProjectId/batches/{batchUid}/file' \-H "Authorization: Bearer $smartlingToken" \-F "file=@file.properties;type=text/plain" \-F "fileUri=file.properties" \-F "fileType=javaProperties" \-F "localeIdsToAuthorize[]=fr-FR" \-F "localeIdsToAuthorize[]=ru-RU"
            Responses:
                202 : ACCEPTED
                404 : Batch provided in path is not found
            details :  https://api-reference.smartling.com/#operation/uploadFileToJobBatchV2
        """
        textData = open(smartlingApiSdk.__path__[0]+'/resources/java.properties', 'rb').read().decode('utf-8', 'ignore')
        batchUid=self.batch_uid
        file=textData
        fileUri=self.file_uri
        fileType='javaProperties'
        authorize=False
        localeIdsToAuthorize=["zh-TW",]
        callbackUrl='https://www.callback.com/smartling/python/sdk/jb2.test'
        res, status = self.job_batches_v2_api.uploadFileToJobBatchV2(batchUid=batchUid, file=file, fileUri=fileUri, fileType=fileType, authorize=authorize, localeIdsToAuthorize=localeIdsToAuthorize, callbackUrl=callbackUrl)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('uploadFileToJobBatchV2', 'OK')


    def checkProcessBatchActionV2(self):
        """
            method  :  PUT
            api url :  /job-batches-api/v2/projects/{projectId}/batches/{batchUid}
            as curl :  curl -X PUT \'https://api.smartling.com/job-batches-api/v2/projects/$smartlingProjectId/batches/$batchUid' \-H "Authorization: Bearer $smartlingToken" \-H "Content-Type: application/json" \-d '{ "action": "CANCEL_FILE", "fileUri": "file1.xml", "reason": "Requested asset doesn't exist in Zendesk" }'
            Responses:
                200 : SUCCESS
                404 : Batch provided in path is not found
            details :  https://api-reference.smartling.com/#operation/processBatchActionV2
        """
        batchUid=self.batch_uid
        action='CANCEL_FILE'
        fileUri='file_to_cancel_later'
        reason='test reason'
        res, status = self.job_batches_v2_api.processBatchActionV2(batchUid=batchUid, action=action, fileUri=fileUri, reason=reason)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('processBatchActionV2', 'OK')



def example():
    t = testJobBatchesV2Api()
    t.setUp()
    t.checkCreateJobBatchV2()
    t.checkGetJobBatchesListV2()
    t.checkGetJobBatchStatusV2()
    t.checkUploadFileToJobBatchV2()
    t.checkProcessBatchActionV2()
    t.tearDown()

if __name__ == '__main__':
    example()




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""


from smartlingApiSdk.ApiV2 import ApiV2

class ContextApi(ApiV2):

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders, env=env)

    def uploadNewVisualContext(self, name='', content='', **kwargs):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/contexts
            as curl :  curl -X POST -H "Authorization: Bearer $smartlingToken" -F "content=@context1.png;type=image/png" -F "name=context1.png" "https://api.smartling.com/context-api/v2/projects/$smartlingProjectId/contexts"
            Responses:
                200 : OK
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/uploadNewVisualContext
        """
        kw = {
            'name':name,
            'content':self.processFile(content),
        }
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/contexts')
        return self.uploadMultipart(url, kw)


    def getVisualContextsListByProject(self, nameFilter='', offset='', type='', **kwargs):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/contexts
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getVisualContextsListByProject
        """
        kw = {
            'nameFilter':nameFilter,
            'offset':offset,
            'type':type,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/contexts', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getVisualContextInfo(self, contextUid, **kwargs):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/contexts/{contextUid}
            Responses:
                200 : OK
                404 : Context not found
            details :  https://api-reference.smartling.com/#operation/getVisualContextInfo
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/contexts/{contextUid}', contextUid=contextUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def deleteVisualContext(self, contextUid, **kwargs):
        """
            method  :  DELETE
            api url :  /context-api/v2/projects/{projectId}/contexts/{contextUid}
            Responses:
                200 : OK
                404 : Context not found
            details :  https://api-reference.smartling.com/#operation/deleteVisualContext
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/contexts/{contextUid}', contextUid=contextUid, **kwargs)
        response, status = self.command('DELETE', url, kw)
        return response, status


    def deleteVisualContextsAsync(self, contextUids=[], **kwargs):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/contexts/remove/async
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/deleteVisualContextsAsync
        """
        kw = {
            'contextUids':contextUids,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/contexts/remove/async', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def downloadVisualContextFileContent(self, contextUid, **kwargs):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/contexts/{contextUid}/content
            Responses:
                200 : OK
                404 : Context not found
            details :  https://api-reference.smartling.com/#operation/downloadVisualContextFileContent
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/contexts/{contextUid}/content', contextUid=contextUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def runAutomaticContextMatching(self, contextUid, contentFileUri='', stringHashcodes=[], overrideContextOlderThanDays=0, **kwargs):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/contexts/{contextUid}/match/async
            Responses:
                202 : ACCEPTED
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/runAutomaticContextMatching
        """
        kw = {
            'contentFileUri':contentFileUri,
            'stringHashcodes':stringHashcodes,
            'overrideContextOlderThanDays':overrideContextOlderThanDays,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/contexts/{contextUid}/match/async', contextUid=contextUid, **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def uploadAndMatchVisualContext(self, content, name='', matchParams='', **kwargs):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/contexts/upload-and-match-async
            Responses:
                202 : ACCEPTED
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/uploadAndMatchVisualContext
        """
        kw = {
            'content':self.processFile(content),
            'name':name,
            'matchParams':matchParams,
        }
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/contexts/upload-and-match-async')
        return self.uploadMultipart(url, kw)


    def getAsyncContextMatchResults(self, matchId, **kwargs):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/match/{matchId}
            Responses:
                200 : OK
                404 : Match request expired or does not exist
            details :  https://api-reference.smartling.com/#operation/getAsyncContextMatchResults
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/match/{matchId}', matchId=matchId, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getAsyncProcessResults(self, processUid, **kwargs):
        """
            method  :  GET
            api url :  /context-api/v2/projects/{projectId}/processes/{processUid}
            Responses:
                200 : OK
                404 : Process request expired or does not exist
            details :  https://api-reference.smartling.com/#operation/getAsyncProcessResults
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/processes/{processUid}', processUid=processUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def createStringToContextBindings(self, bindings=[], **kwargs):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/bindings
            Responses:
                200 : OK
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/createStringToContextBindings
        """
        kw = {
            'bindings':bindings,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/bindings', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getBindings(self, offset='', stringHashcodes=[], contentFileUri='', contextUid='', bindingUids=[], **kwargs):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/bindings/list
            Responses:
                200 : OK
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/getBindings
        """
        kw = {
            'offset':offset,
            'stringHashcodes':stringHashcodes,
            'contentFileUri':contentFileUri,
            'contextUid':contextUid,
            'bindingUids':bindingUids,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/bindings/list', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def deleteBindings(self, stringHashcodes=[], contentFileUri='', contextUid='', bindingUids=[], **kwargs):
        """
            method  :  POST
            api url :  /context-api/v2/projects/{projectId}/bindings/remove
            Responses:
                200 : OK
                400 : Validation error
            details :  https://api-reference.smartling.com/#operation/deleteBindings
        """
        kw = {
            'stringHashcodes':stringHashcodes,
            'contentFileUri':contentFileUri,
            'contextUid':contextUid,
            'bindingUids':bindingUids,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/context-api/v2/projects/{projectId}/bindings/remove', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status




#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
 """


class Code:
    def __init__(self, value):
        self.value = value

    def __str__(self):
        return self.value


class ApiCore:
    def __init__(self, swaggerDict):
        self.swaggerDict = swaggerDict

    def resolveRef(self, ref):
        if not ref.startswith('#/'):
            raise Exception('Unknown $ref:%s' % ref)
        pth = ref[2:].split('/')
        dct = self.swaggerDict
        lastname = ''
        for p in pth:
            dct = dct[p]
            lastname = p
        return dct, lastname


class Parameter(ApiCore):
    def __init__(self, param_dict, swaggerDict):
        ApiCore.__init__(self, swaggerDict)
        self._required = False
        self._name = ""
        param_names = ['name', 'description', 'in', 'required', 'schema']
        self.processParams(param_names, param_dict)
        self._type = "string"

        if self._schema:
            if '$ref' == list(self._schema.keys())[0]:
                self._schema, refname = self.resolveRef(self._schema['$ref'])
            self._type = self._schema['type']
            self._default = self._schema.get('default', None)

    def processParams(self, param_names, param_dict):
        for name in param_names:
            n = param_dict.get(name, None)
            if 'name' == name:
                n = n.replace('[]', '')
            setattr(self, '_' + name, n)

    def getParamForName(self):
        if self._required:
            return self._name
        return "%s=%s" % (self._name, self.getDefault())

    def getParamForMethodCall(self, values={}):
        value = values.get(self._name, self._name)
        if type(value) == type(Code):
            pass
        elif value != self._name and type(value) == str:
            value = "'" + value + "'"
        if 'accountUid' == self._name:
            value = 'self.MY_ACCOUNT_UID'
        return "%s=%s" % (self._name, value)

    def getDefault(self):
        default = getattr(self, '_default', None)
        if default is None:
            default = "''"
        if "string" == self._type and default != "''":
            default = "'" + default + "'"
        if 'array' == self._type:
            return '[]'
        if 'integer' == self._type and default == "''":
            return '0'
        return default


class MultipartProperty(Parameter):
    def __init__(self, name, paramDict, swaggerDict):
        self._format = None
        self._type = None
        param_names = ['description', 'format', 'type', 'default', 'example']
        self.processParams(param_names, paramDict)
        self._required = False
        self._name = name.replace('[]', '').split(' ')[0]
        self.isRequestBody = False
        self.swaggerDict = swaggerDict

    def setRequired(self):
        self._required = True

    def __str__(self):
        if self._format:
            return "%s : %s-%s" % (self._name, self._type, self._format)
        return "%s : %s" % (self._name, self._type)





#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""


from smartlingApiSdk.ApiV2 import ApiV2

class JobBatchesV2Api(ApiV2):

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None, permanentHeaders={}, env='prod'):
        ApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings, permanentHeaders=permanentHeaders, env=env)

    def createJobBatchV2(self, authorize, translationJobUid, fileUris, localeWorkflows=[], **kwargs):
        """
            method  :  POST
            api url :  /job-batches-api/v2/projects/{projectId}/batches
            as curl :  curl -X POST "https://api.smartling.com/job-batches-api/v2/projects/$smartlingProjectId/batches" -H "Authorization: Bearer $smartlingToken" -H "Content-Type: application/json" -d '{"translationJobUid": "$translationJobUid", "authorize": true, "fileUris": ["example.json", "test.xml"]}'
            Responses:
                200 : OK
                404 : provided translationJobUid is not found in the TMS
            details :  https://api-reference.smartling.com/#operation/createJobBatchV2
        """
        kw = {
            'authorize':authorize,
            'translationJobUid':translationJobUid,
            'fileUris':fileUris,
            'localeWorkflows':localeWorkflows,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/job-batches-api/v2/projects/{projectId}/batches', **kwargs)
        response, status = self.commandJson('POST', url, kw)
        return response, status


    def getJobBatchesListV2(self, translationJobUid='', status='', sortBy='createdDate', orderBy='desc', offset=0, limit=20, **kwargs):
        """
            method  :  GET
            api url :  /job-batches-api/v2/projects/{projectId}/batches
            as curl :  curl -X GET \'https://api.smartling.com/job-batches-api/v2/projects/$smartlingProjectId/batches?translationJobUid={translationJobUid}&status={status}&sortBy=createdDate&orderBy=desc&offset=0&limit=20' \-H "Authorization: Bearer $smartlingToken"
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getJobBatchesListV2
        """
        kw = {
            'translationJobUid':translationJobUid,
            'status':status,
            'sortBy':sortBy,
            'orderBy':orderBy,
            'offset':offset,
            'limit':limit,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/job-batches-api/v2/projects/{projectId}/batches', **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def getJobBatchStatusV2(self, batchUid, **kwargs):
        """
            method  :  GET
            api url :  /job-batches-api/v2/projects/{projectId}/batches/{batchUid}
            Responses:
                200 : OK
                404 : Batch provided in path is not found
            details :  https://api-reference.smartling.com/#operation/getJobBatchStatusV2
        """
        kw = {
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/job-batches-api/v2/projects/{projectId}/batches/{batchUid}', batchUid=batchUid, **kwargs)
        response, status = self.command('GET', url, kw)
        return response, status


    def processBatchActionV2(self, batchUid, action, fileUri, reason='', **kwargs):
        """
            method  :  PUT
            api url :  /job-batches-api/v2/projects/{projectId}/batches/{batchUid}
            as curl :  curl -X PUT \'https://api.smartling.com/job-batches-api/v2/projects/$smartlingProjectId/batches/$batchUid' \-H "Authorization: Bearer $smartlingToken" \-H "Content-Type: application/json" \-d '{ "action": "CANCEL_FILE", "fileUri": "file1.xml", "reason": "Requested asset doesn't exist in Zendesk" }'
            Responses:
                200 : SUCCESS
                404 : Batch provided in path is not found
            details :  https://api-reference.smartling.com/#operation/processBatchActionV2
        """
        kw = {
            'action':action,
            'fileUri':fileUri,
            'reason':reason,
        }
        kw.update(kwargs)
        url = self.urlHelper.getUrl('/job-batches-api/v2/projects/{projectId}/batches/{batchUid}', batchUid=batchUid, **kwargs)
        response, status = self.commandJson('PUT', url, kw)
        return response, status


    def uploadFileToJobBatchV2(self, batchUid, file, fileUri, fileType, authorize=False, localeIdsToAuthorize=[], callbackUrl='', directives={}, **kwargs):
        """
            method  :  POST
            api url :  /job-batches-api/v2/projects/{projectId}/batches/{batchUid}/file
            as curl :  curl -X POST \'https://api.smartling.com/job-batches-api/v2/projects/$smartlingProjectId/batches/{batchUid}/file' \-H "Authorization: Bearer $smartlingToken" \-F "file=@file.properties;type=text/plain" \-F "fileUri=file.properties" \-F "fileType=javaProperties" \-F "localeIdsToAuthorize[]=fr-FR" \-F "localeIdsToAuthorize[]=ru-RU"
            Responses:
                202 : ACCEPTED
                404 : Batch provided in path is not found
            details :  https://api-reference.smartling.com/#operation/uploadFileToJobBatchV2
        """
        kw = {
            'file':self.processFile(file),
            'fileUri':fileUri,
            'fileType':fileType,
            'authorize':authorize,
            'localeIdsToAuthorize':localeIdsToAuthorize,
            'callbackUrl':callbackUrl,
        }
        self.addLibIdDirective(kw)
        self.processDirectives(kw, directives)
        url = self.urlHelper.getUrl('/job-batches-api/v2/projects/{projectId}/batches/{batchUid}/file', batchUid=batchUid)
        return self.uploadMultipart(url, kw)





#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import os
import sys
import time, datetime

sys.path += [os.path.abspath('../'), os.path.abspath('../../')]  # allow to import ../smartlingApiSdk.api

import smartlingApiSdk
from smartlingApiSdk.api.AccountProjectsApi import AccountProjectsApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

isPython3 =  sys.version_info[:2] >= (3,0)

def assert_equal(a,b, comment=''):
    if a != b :
        err = "Assertion Failed: '%s' != '%s' %s" % (a,b, comment)
        if not isPython3 and type(err) == str:
            err = err.decode('utf-8', 'ignore')
        raise Exception(repr(err))

class testAccountProjectsApi(object):

    CODE_SUCCESS_TOKEN = 'SUCCESS'
    ACCEPTED_TOKEN = 'ACCEPTED'

    def tearDown(self):
        print("tearDown", "OK")

    def setUp(self):
        credentials = Credentials('stg') #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
        self.MY_LOCALE = credentials.MY_LOCALE

        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print("can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********")
            return

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None

        self.account_projects_api = AccountProjectsApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings, env='stg')

        print("setUp", "OK", "\n")


    def checkGetProjectsByAccount(self):
        """
            method  :  GET
            api url :  /accounts-api/v2/accounts/{accountUid}/projects
            as curl :  curl -H "Authorization: Bearer $smartlingToken" https://api.smartling.com/accounts-api/v2/accounts/$smartlingAccountId/projects
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getProjectsByAccount
        """
        accountUid=self.MY_ACCOUNT_UID
        res, status = self.account_projects_api.getProjectsByAccount(accountUid=self.MY_ACCOUNT_UID)


        assert_equal(True, res.data.totalCount > 0)
        project_name = ''
        for p in res.data.items:
            if p['projectId'] == self.MY_PROJECT_ID:
                project_name = p['projectName']
        assert_equal('test variants', project_name)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getProjectsByAccount', 'OK')


    def checkGetProjectDetails(self):
        """
            method  :  GET
            api url :  /projects-api/v2/projects/{projectId}
            as curl :  curl -H "Authorization: Bearer $smartlingToken" https://api.smartling.com/projects-api/v2/projects/$smartlingProjectId
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getProjectDetails
        """
        res, status = self.account_projects_api.getProjectDetails()


        assert_equal(res.data.projectId, self.MY_PROJECT_ID)
        assert_equal(res.data.projectName, 'test variants')
        assert_equal(res.data.accountUid, self.MY_ACCOUNT_UID)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getProjectDetails', 'OK')


    def checkAddLocaleToProject(self):
        """
            method  :  POST
            api url :  /projects-api/v2/projects/{projectId}/targetLocales
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/addLocaleToProject
        """
        defaultWorkflowUid='748398939979'
        localeId='es-MX'
        res, status = self.account_projects_api.addLocaleToProject(defaultWorkflowUid=defaultWorkflowUid, localeId=localeId)


        assert_equal(res.data.projectId, self.MY_PROJECT_ID)
        assert_equal(res.data.projectName, 'test variants')
        assert_equal(res.data.accountUid, self.MY_ACCOUNT_UID)
        locales = [l['localeId'] for l in res.data.targetLocales]
        assert_equal(True, 'es-MX' in locales)

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('addLocaleToProject', 'OK')


    def checkCopyProject(self):
        """
            method  :  POST
            api url :  /projects-api/v2/projects/{projectId}/copy
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/copyProject
        """
        projectName='python SDK test'
        targetLocaleIds=['es-MX', 'zh-TW']
        res, status = self.account_projects_api.copyProject(projectName=projectName, targetLocaleIds=targetLocaleIds)


        assert_equal(res.code, 'ACCEPTED')

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('copyProject', 'OK')
        self.copy_process_uid  = res.data.processUid


    def checkGetProjectCopyRequestStatus(self):
        """
            method  :  GET
            api url :  /projects-api/v2/projects/{projectId}/copy/{processUid}
            Responses:
                200 : OK
            details :  https://api-reference.smartling.com/#operation/getProjectCopyRequestStatus
        """
        processUid=self.copy_process_uid
        res, status = self.account_projects_api.getProjectCopyRequestStatus(processUid=processUid)


        assert_equal(res.data.processUid, self.copy_process_uid)
        assert_equal(True, res.data.processState in ['IN_PROGRESS','COMPLETED'])

        assert_equal(True, status in [200,202])
        assert_equal(True, res.code in [self.CODE_SUCCESS_TOKEN, self.ACCEPTED_TOKEN])
        print('getProjectCopyRequestStatus', 'OK')



    def test_all(self):
        t = self
        t.checkGetProjectsByAccount()
        t.checkGetProjectDetails()
        t.checkAddLocaleToProject()
        t.checkCopyProject()
        t.checkGetProjectCopyRequestStatus()



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
 """

from builder.Parameters import Code
from builder.ExampleData import TestData

testsOrder = [
    'getTagsListByProject',
    'getAllTagsForStrings',
    'addTagToStrings',
    'removeTagsFromStrings',
    'addTagToStrings',
    'removeAllTagsFromStrings'
]

extraInitializations = '''
'''

testEnvironment = 'stg'

testDecorators = {
    'getTagsListByProject':TestData(
        {
        },
        customTestCheck='''
assert_equal(True, hasattr(res.data, 'items'))
'''
    ),

   'getAllTagsForStrings' : TestData (
       {
           'stringHashcodes' : Code("['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here")
       },
       customTestCheck='''
assert_equal(True, hasattr(res.data, 'items'))
assert_equal('e1159037badca0a2a618f62c50eff1bb', res.data.items[0]['stringHashcode'])
'''
   ),

   'addTagToStrings' : TestData (
       {
           'stringHashcodes' : Code("['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here"),
           'tags' : Code("['Uno', 'Dos']")
       },
       customTestCheck='''
assert_equal([], res.errors)
'''
   ),

   'removeTagsFromStrings' : TestData (
       {
           'stringHashcodes' : Code("['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here"),
           'tags' : Code("['Uno', 'Dos']")
       },
       customTestCheck='''
assert_equal([], res.errors)
'''
   ),

    'removeAllTagsFromStrings' : TestData (
    {
       'stringHashcodes' : Code("['e1159037badca0a2a618f62c50eff1bb', ] # use your string hashcodes list here"),
    },
       customTestCheck='''
assert_equal([], res.errors)
'''
   ),

}


#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import io
import os
import sys
import time
import zipfile
from datetime import date

from nose.tools import assert_equal

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

import smartlingApiSdk
from smartlingApiSdk.api.FilesApi import FilesApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.version import version
from smartlingApiSdk.Credentials import Credentials
from smartlingApiSdk.Constants import FileTypes

isPython3 =  sys.version_info[:2] >= (3,0)

if isPython3:
    newline = b"\n"
else:
    newline = "\n"
    import StringIO

class testFapiV2(object):

    FILE_NAME = "java.properties"
    FILE_NAME_16 = "javaUTF16.properties"
    FILE_TYPE = "javaProperties"
    FILE_TYPE_CSV = "csv"
    FILE_PATH = smartlingApiSdk.__path__[0]+"/resources/"
    FILE_NAME_NEW = "java.properties.renamed"
    FILE_NAME_NEW_16 = "javaUTF16.properties.renamed"
    FILE_NAME_CSV = "test.csv"

    FILE_NAME_IMPORT_ORIG = "test_import.xml"
    FILE_NAME_IMPORT_TRANSLATED = "test_import_es.xml"
    FILE_TYPE_IMPORT = "android"

    CALLBACK_URL = "http://google.com/?q=hello"

    CODE_SUCCESS_TOKEN = 'SUCCESS'


    def setUp(self):
        credentials = Credentials() #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID
        self.MY_LOCALE = credentials.MY_LOCALE

        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None
        self.fapi = FilesApi(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings)
        unique_suffix = "_" + version + "_" + repr(time.time())
        self.uri = self.FILE_NAME + unique_suffix
        self.doUpload(self.FILE_NAME, self.uri, self.FILE_TYPE)

        self.uri_csv = self.FILE_NAME_CSV + unique_suffix

        self.uri16 = self.FILE_NAME_16 + unique_suffix
        self.doUpload(self.FILE_NAME_16, self.uri16, self.FILE_TYPE)

        self.uri_to_rename = self.FILE_NAME_NEW + unique_suffix
        self.uri_import = self.FILE_NAME_IMPORT_ORIG + unique_suffix

        print("setUp", "OK", "\n\n\n")


    def tearDown(self):
        res, status = self.fapi.deleteUploadedSourceFile(self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        res, status = self.fapi.deleteUploadedSourceFile(self.uri16)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        print("tearDown", "OK")

    def doUpload(self, name, uri, type):
        #ensure file is uploaded which is necessary for all tests
        uniqueUriForUploadTestFile = uri
        localeIdsToAuthorize = [self.MY_LOCALE]
        res, status = self.fapi.uploadSourceFile(self.FILE_PATH + name, fileType=type, fileUri = uniqueUriForUploadTestFile, localeIdsToAuthorize = localeIdsToAuthorize )

        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        return res, status

    def testFileList(self):
        res, status = self.fapi.getRecentlyUploadedSourceFilesList(fileTypes=[FileTypes.android, FileTypes.javaProperties])
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        uris = [x['fileUri'] for x in res.data.items]

        assert_equal(True, self.uri in uris)
        assert_equal(True, self.uri16 in uris)

        print("testFileList", "OK")

    def testFileListTypes(self):
        res, status = self.fapi.getFileTypesList()
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        print("testFileListTypes", "OK")

    def testGet(self):
        res, status = self.fapi.downloadTranslatedFileSingleLocale(self.MY_LOCALE, self.uri)
        assert_equal(200, status)

        resp_lines_count = len(res.split(newline))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME, "rb").read().split(newline) )
        assert_equal(resp_lines_count, file_lines_count)

        print("testGet", "OK")

        res, status = self.fapi.downloadTranslatedFileSingleLocale(self.MY_LOCALE, self.uri16)
        assert_equal(200, status)

        resp_lines_count = len(res.split(newline))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME_16, "rb").read().split(newline) )
        assert_equal(resp_lines_count, file_lines_count)
        print("testGet Utf16", "OK")


    def testGetMultipleLocalesAsZip(self):
        res, status = self.fapi.downloadMultipleTranslatedFiles([self.uri,self.uri16], [self.MY_LOCALE])
        assert_equal(200, status)

        if isPython3:
            zfile = zipfile.ZipFile(io.BytesIO(res))
        else:
            zfile = zipfile.ZipFile(StringIO.StringIO(res))
        names = zfile.namelist()

        assert_equal(True, self.MY_LOCALE+"/"+self.uri in names)
        assert_equal(True, self.MY_LOCALE+"/"+self.uri16 in names)

        print("testGetMultipleLocalesAsZip", "OK")


    def testGetAllLocalesZip(self):
        res, status = self.fapi.downloadTranslatedFilesAllLocales(self.uri)
        assert_equal(200, status)


        if isPython3:
            zfile = zipfile.ZipFile(io.BytesIO(res))
        else:
            zfile = zipfile.ZipFile(StringIO.StringIO(res))
        names = zfile.namelist()

        assert_equal(True, self.MY_LOCALE+"/"+self.uri in names)

        print("testGetAllLocalesZip", "OK")


    def testGetOriginal(self):
        res, status = self.fapi.downloadSourceFile(self.uri)
        assert_equal(200, status)

        orig = open(self.FILE_PATH + self.FILE_NAME, "rb").read()
        assert_equal(res, orig)

        print("testGetOriginal", "OK")

        res, status = self.fapi.downloadSourceFile(self.uri16)
        assert_equal(200, status)

        resp_lines_count = len(res.split(newline))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME_16, "rb").readlines() )
        assert_equal(resp_lines_count, file_lines_count)
        print("testGetOriginal Utf16", "OK")

    def testStatus(self):
        res, status = self.fapi.getFileTranslationStatusAllLocales(self.uri)

        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        assert_equal(res.data.fileUri, self.uri)
        assert_equal(True, len(res.data.items) > 0)

        print("testStatus", "OK")


    def testStatusLocale(self):
        res, status = self.fapi.getFileTranslationStatusSingleLocale(self.MY_LOCALE, self.uri)

        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        assert_equal(res.data.fileUri, self.uri)
        assert_equal(res.data.fileType, self.FILE_TYPE)

        print("testStatusLocale", "OK")

    def testFileRename(self):

        res, status = self.fapi.renameUploadedSourceFile(self.uri, self.uri_to_rename)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        #rename it back so tearDown could remove it
        res, status = self.fapi.renameUploadedSourceFile(self.uri_to_rename, self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        print("testFileRename", "OK")

    def testLastModified(self):
        resp, status = self.fapi.getTranslatedFileLastModifiedDateSingleLocale(self.MY_LOCALE, self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)

        lm_date = resp.data.lastModified[:10]
        assert_equal(lm_date,  date.today().isoformat())

        resp, status = self.fapi.getTranslatedFileLastModifiedDateSingleLocale(self.MY_LOCALE, self.uri16)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)

        lm_date = resp.data.lastModified[:10]
        assert_equal(lm_date,  date.today().isoformat())

        print("testLastModified", "OK")

    def testLastModifiedAll(self):
        resp, status = self.fapi.getTranslatedFileLastModifiedDateAllLocales(self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)
        assert_equal(True, len(resp.data.items) > 0)

        resp, status = self.fapi.getTranslatedFileLastModifiedDateAllLocales(self.uri16)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)
        assert_equal(True, len(resp.data.items) > 0)

        print("testLastModifiedAll", "OK")

    def testImport(self):
        res, status = self.fapi.uploadSourceFile(self.FILE_PATH + self.FILE_NAME_IMPORT_ORIG, fileType = self.FILE_TYPE_IMPORT , fileUri=self.uri_import)

        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        originalPath = self.FILE_PATH + self.FILE_NAME_IMPORT_ORIG
        translatedPath = self.FILE_PATH + self.FILE_NAME_IMPORT_TRANSLATED

        resp, status = self.fapi.importFileTranslations(file=translatedPath, fileType=self.FILE_TYPE_IMPORT, localeId=self.MY_LOCALE, fileUri=self.uri_import, translationState="PUBLISHED")

        assert_equal(resp.code, self.CODE_SUCCESS_TOKEN)
        assert_equal(resp.data.wordCount, 2)
        assert_equal(resp.data.stringCount, 2)
        assert_equal(resp.data.translationImportErrors, [])

        res, status = self.fapi.deleteUploadedSourceFile(self.uri_import)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        print("testImport", "OK")

    def testListAuthorizedLocales(self):
        resp, status = self.fapi.getTranslatedFileLastModifiedDateAllLocales(self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)
        assert_equal(True, len(resp.data.items) > 0)

        locales = [x['localeId'] for x in resp.data.items]
        assert_equal(True, self.MY_LOCALE in locales)
        print("testListAuthorizedLocales", "OK")

    def testGetTranslations(self):
        res, status = self.fapi.exportFileTranslations((self.MY_LOCALE),self.FILE_PATH+self.FILE_NAME, self.uri)

        assert_equal(200, status)


        resp_lines_count = len(res.split(newline))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME, "rb").readlines() )
        assert_equal(resp_lines_count, file_lines_count)

        print("testGetTranslations", "OK")



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

#FileApi class implementation

from .Constants import ReqMethod
from .UrlV2Helper import UrlV2Helper
from .ApiV2 import ApiV2

class ProjectsApiV2(ApiV2):
    """ basic class implementing Projects/Accounts api calls """

    def __init__(self, userIdentifier, userSecret, proxySettings=None, permanentHeaders={}):
        outdated = '''
This api is outdated and is not supported anymore!
You still can use it by commenting this exception.
But it is advised to use new api version.
Please check examples for current api usage.'''
        raise Exception(outdated)
        ApiV2.__init__(self, userIdentifier, userSecret, proxySettings, permanentHeaders=permanentHeaders)
        self.urlHelper = UrlV2Helper(None)

    def commandProjectDetails(self, projectId):    
        """ http://docs.smartling.com/pages/API/v2/Projects/Project-Details/ """
        kw = {}
        url = self.urlHelper.getUrl(self.urlHelper.PROJECT_DETAILS, projectId=projectId)
        return self.command(ReqMethod.GET, url, kw)

    def commandProjects(self, accountUid):    
        """ http://docs.smartling.com/pages/API/v2/Projects/List-Projects/ """
        kw = {}
        url = self.urlHelper.getUrl(self.urlHelper.PROJECTS, accountUid = accountUid)
        return self.command(ReqMethod.GET, url, kw)
        

       


#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
"""

import sys

isPython3 = sys.version_info[:2] >= (3,0)

if isPython3:
    import urllib.request as urllib2
    import urllib.error
    HTTPError = urllib.error.HTTPError
    from urllib.parse import urlencode
else:
    import urllib, urllib2
    HTTPError = urllib2.HTTPError
    from urllib import urlencode

from .Constants import ReqMethod
from .Settings import Settings
from .MultipartPostHandler import MultipartPostHandler
import ssl

class HttpClient:
    protocol = 'https://'

    def __init__(self, host, proxySettings=None, permanentHeaders={}):
        self.host = host
        self.proxySettings = proxySettings
        self.permanentHeaders = permanentHeaders
        self.ignore_errors = False
        self.list_brackets = True  # Add [] suffix to GET list keys in urls, like &hashcodes[]=abcd, required by Files API
        self.force_multipart = True

    def getHttpResponseAndStatus(self, method, uri, params, handler=None, extraHeaders={}, requestBody="", context=None):
        self.installOpenerWithProxy(handler)
        if handler:
            prarms = self.encodeListParams(params)
        else:
            params = self.encodeParametersAsString(params)

        headers = {"User-Agent": Settings.userAgent}
        for k, v in list(extraHeaders.items())+list(self.permanentHeaders.items()):
            headers[k] = v
        headers = self.setContentType(method, headers)

        url = self.protocol + self.host + uri
        if method in (ReqMethod.GET, ReqMethod.DELETE) and params:
            url += "?" + params
        req = urllib2.Request(url, params, headers=headers)
        req.get_method = lambda: method

        try:
            if requestBody:
                response = urllib2.urlopen(req, requestBody, context=context)
            else:
                if handler:
                    multipartHandler = MultipartPostHandler()
                    req = multipartHandler.http_request(req, self.force_multipart)
                else:
                    req.data = req.data.encode()
                response = urllib2.urlopen(req, timeout=Settings.requestTimeoutSeconds, context=context)
        except HTTPError as e:
            response = e

        except Exception as e:
            if type(getattr(e, "reason", None)) == getattr(ssl,'SSLCertVerificationError', None):
                raise Exception("\nSome python versions require installation of local ssl certificate!\nuse command:\npip install certifi\nor on macos run command:\nopen /Applications/Python*/Install\ Certificates.command")
            raise e

        if sys.version_info[:2] >= (2, 6):
            status_code = response.getcode()
        else:
            status_code = response.code

        headers = dict(response.info())

        response_data = response.read()
        if status_code not in [200, 202] and not self.ignore_errors:
            print("Non 200 response:%s   RequestId:%s   URL:%s   response:%s" %
                  (status_code, headers.get("X-SL-Requestid","Unknown"), url, response_data)
                 )
        return response_data, status_code, headers

    def installOpenerWithProxy(self, handler):
        if self.proxySettings:
            if self.proxySettings.username:
                proxyStr = 'http://%s:%s@%s:%s' % (
                self.proxySettings.username, self.proxySettings.passwd, self.proxySettings.host,
                self.proxySettings.port)
            else:
                proxyStr = 'http://%s:%s' % (self.proxySettings.host, self.proxySettings.port)

            opener = urllib2.build_opener(
                handler or urllib2.HTTPHandler(),
                handler or urllib2.HTTPSHandler(),
                urllib2.ProxyHandler({"https": proxyStr}))
            urllib2.install_opener(opener)
        elif handler:
            opener = urllib2.build_opener(MultipartPostHandler)
            urllib2.install_opener(opener)

    def encodeParametersAsString(self, params):
        #processes list parameters separately i.e. {key:[v1, v2]} is encoded as 'key[]=v1&key[]=v2'
        result = ""
        for k, v in list(params.items()):
            if type(v) == bool: params[k] = str(v).lower()
            if type(v) == type([]) or type(v) == type(()):
                del params[k]
                for single in v:
                    if len(result) > 0:
                        result += "&"
                    keyList = k
                    if self.list_brackets:
                        keyList += "[]"
                    dct = {keyList: single}
                    result += urlencode(dct)

        if params:
            if len(result) > 0:
                result += "&"

            result += urlencode(params)

        return result

    def encodeListParams(self, params):
        for k, v in list(params.items()):
            if type(v) == bool:
                params[k] = str(v).lower()
            if type(v) == type([]) or type(v) == type(()):
                del params[k]
                params[k + '[]'] = ",".join(v)
        return params

    def setContentType(self, method, headers):
        ct = "Content-Type"
        if method in (ReqMethod.POST, ReqMethod.PUT) and ct not in headers:
            headers[ct] = "application/x-www-form-urlencoded"
        return headers



#!/usr/bin/python
# -*- coding: utf-8 -*-


""" Copyright 2012-2021 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limit
"""

from builder.Parameters import Code
from builder.ExampleData import TestData

testsOrder = [
    'uploadSourceFile',
    'downloadSourceFile',
    'getFileTranslationStatusAllLocales',
    'getFileTranslationStatusSingleLocale',
    'downloadTranslatedFileSingleLocale',
    'downloadTranslatedFilesAllLocales',
    'downloadMultipleTranslatedFiles',
    'getRecentlyUploadedSourceFilesList',
    'getFileTypesList',
    'renameUploadedSourceFile',
    'getTranslatedFileLastModifiedDateSingleLocale',
    'getTranslatedFileLastModifiedDateAllLocales',
    'importFileTranslations',
    'exportFileTranslations',
    'getRecentlyPublishedFilesList',
    'deleteUploadedSourceFile',
]

teardown = '''
        res, status = self.files_api.deleteUploadedSourceFile(self.uri16)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        res, status = self.files_api.deleteUploadedSourceFile(self.uri_json)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
'''

imports = '''
from smartlingApiSdk.Constants import FileTypes
from datetime import date
import zipfile
if isPython3:
    import io
else:
    import StringIO

if isPython3:
    newline = b"\\n"
else:
    newline = "\\n"
'''

extraInitializations = '''
        self.extraInitializations()

    def extraInitializations(self):
        self.FILE_NAME = "java.properties"
        self.FILE_NAME_16 = "javaUTF16.properties"
        self.FILE_TYPE = "javaProperties"
        self.FILE_TYPE_CSV = "csv"
        self.FILE_PATH = smartlingApiSdk.__path__[0]+"/resources/"
        self.FILE_NAME_NEW = "java.properties.renamed"
        self.FILE_NAME_NEW_16 = "javaUTF16.properties.renamed"
        self.FILE_NAME_CSV = "test.csv"
    
        self.FILE_NAME_IMPORT_ORIG = "test_import.xml"
        self.FILE_NAME_IMPORT_TRANSLATED = "test_import_es.xml"
        self.FILE_TYPE_IMPORT = "android"

        self.CALLBACK_URL = "http://google.com/?q=hello"

        unique_suffix = "_" + repr(time.time())
        self.uri = self.FILE_NAME + unique_suffix 
        self.uri16 = self.FILE_NAME_16 + unique_suffix 
        res, status = self.files_api.uploadSourceFile(self.FILE_PATH + self.FILE_NAME_16, fileType=self.FILE_TYPE, fileUri = self.uri16, localeIdsToAuthorize = [self.MY_LOCALE] )
        
        self.uri_to_rename = self.FILE_NAME_NEW + unique_suffix
        self.uri_import = self.FILE_NAME_IMPORT_ORIG + unique_suffix

        self.file_json = "simple.json"
        self.uri_json = unique_suffix + self.file_json
        res, status = self.files_api.uploadSourceFile(self.FILE_PATH + self.file_json, fileType="json", fileUri=self.uri_json, localeIdsToAuthorize = [self.MY_LOCALE] )

    def getZipFile(self, res):
        if isPython3:
            return zipfile.ZipFile(io.BytesIO(res))
        else:
            return zipfile.ZipFile(StringIO.StringIO(res))
'''

testEnvironment = 'stg'

testDecorators = {
    'uploadSourceFile':TestData(
        {
            "file":Code('self.FILE_PATH + self.FILE_NAME'),
            "fileUri" : Code('self.uri'),
            "fileType" : Code('self.FILE_TYPE'),
            'localeIdsToAuthorize' : Code('[self.MY_LOCALE]'),
        },
        customTestCheck='''
assert_equal(res.data.wordCount, 6)
assert_equal(res.data.stringCount, 6)
'''
    ),

    'deleteUploadedSourceFile' : TestData(
        {
            'fileUri' :  Code('self.uri')
        }
    ),

    'downloadSourceFile' : TestData(
        {
            'fileUri' :  Code('self.uri_json')
        },
        customTestCheck='''
orig = open(self.FILE_PATH + self.file_json , "rb").read()
assert_equal(res, orig)
''',
        isApiV2Response= False,
    ),

    'getFileTranslationStatusAllLocales': TestData(
        {
            'fileUri' :  Code('self.uri')
        },
        customTestCheck='''
assert_equal(res.data.fileUri, self.uri)
assert_equal(True, len(res.data.items) > 0)
'''
    ),

    'getFileTranslationStatusSingleLocale': TestData(
        {
            'fileUri' :  Code('self.uri'),
            'localeId' : Code('self.MY_LOCALE')
        },
        customTestCheck='''
assert_equal(res.data.fileUri, self.uri)
assert_equal(res.data.fileType, self.FILE_TYPE)
'''
    ),

    'downloadTranslatedFileSingleLocale':  TestData(
        {
            'fileUri' :  Code('self.uri'),
            'localeId' : Code('self.MY_LOCALE')
        },
        customTestCheck='''
resp_lines_count = len(res.decode('utf-8').split('\\n'))
file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME, "rb").read().decode('utf-8').split('\\n') )
assert_equal(resp_lines_count, file_lines_count)
''',
        isApiV2Response= False,
    ),

    'downloadTranslatedFilesAllLocales' : TestData(
        {
            'fileUri' :  Code('self.uri'),
        },
        customTestCheck='''
zfile = self.getZipFile(res)
names = zfile.namelist()
assert_equal(True, self.MY_LOCALE+'/'+self.uri in names)
''',
        isApiV2Response= False,
    ),

    'downloadMultipleTranslatedFiles' : TestData(
        {
            'fileUris' : Code('[self.uri,self.uri16]'),
            'localeIds': Code("[self.MY_LOCALE, 'zh-TW']"),
        },
        customTestCheck='''
zfile = self.getZipFile(res)
names = zfile.namelist()
assert_equal(True, self.MY_LOCALE+'/'+self.uri in names)
assert_equal(True, self.MY_LOCALE+'/'+self.uri16 in names)
assert_equal(True, 'zh-TW'+'/'+self.uri in names)
assert_equal(True, 'zh-TW'+'/'+self.uri16 in names)
''',
        isApiV2Response= False,
    ),

    'getRecentlyUploadedSourceFilesList' : TestData(
        {
            'fileTypes' : Code('[FileTypes.android, FileTypes.javaProperties]')
        },
        customTestCheck='''
uris = [x['fileUri'] for x in res.data.items]
assert_equal(True, self.uri in uris)
assert_equal(True, self.uri16 in uris)
'''
    ),

    'getFileTypesList' : TestData(
        {
        },
        customTestCheck='''
assert_equal(True, "javaProperties" in res.data.items)
'''
    ),

    'renameUploadedSourceFile' : TestData(
        {
            'fileUri' :  Code('self.uri'),
            'newFileUri' :  Code('self.uri_to_rename'),

        },
        customTestCheck='''
res, status = self.files_api.renameUploadedSourceFile(self.uri_to_rename, self.uri) #rename it back so in the end it could be removed
'''
    ),


    'getTranslatedFileLastModifiedDateSingleLocale' : TestData(
        {
            'fileUri' :  Code('self.uri'),
            'localeId' : Code('self.MY_LOCALE')

        },
        customTestCheck='''
lm_date = res.data.lastModified[:10]
assert_equal(lm_date,  date.today().isoformat())
'''
    ),

    'getTranslatedFileLastModifiedDateAllLocales' : TestData(
        {
            'fileUri' :  Code('self.uri'),

        },
        customTestCheck='''
assert_equal(True, len(res.data.items) > 0)
for l in res.data.items:
    if l['localeId'] == self.MY_LOCALE:
        lm_date = l['lastModified'][:10]
        assert_equal(lm_date,  date.today().isoformat())
'''
    ),

    'importFileTranslations' : TestData(
        {
            'fileUri' :  Code('self.uri_import'),
            'localeId' : Code('self.MY_LOCALE'),
            'file' : Code('self.FILE_PATH + self.FILE_NAME_IMPORT_TRANSLATED'),
            'fileType' : Code('self.FILE_TYPE_IMPORT'),
            'translationState' : 'PUBLISHED',
        },
        ['res, status = self.files_api.uploadSourceFile(self.FILE_PATH + self.FILE_NAME_IMPORT_ORIG, fileType = self.FILE_TYPE_IMPORT , fileUri=self.uri_import)'],
        customTestCheck='''

assert_equal(res.data.wordCount, 2)
assert_equal(res.data.stringCount, 2)
assert_equal(res.data.translationImportErrors, [])

res, status = self.files_api.deleteUploadedSourceFile(self.uri_import)
assert_equal(200, status)
assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

'''
    ),

    'exportFileTranslations' : TestData(
        {
            'fileUri' :  Code('self.uri'),
            'localeId' : Code('self.MY_LOCALE'),
            'file' : Code('self.FILE_PATH+self.FILE_NAME'),
        },
        customTestCheck='''
assert_equal(True, res is not None)
resp_lines_count = len(res.split(newline))
file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME, "rb").readlines() )
assert_equal(resp_lines_count, file_lines_count)
''',
        isApiV2Response= False,
    ),

    'getRecentlyPublishedFilesList' : TestData(
        {
            'publishedAfter': Code('datetime.datetime.fromtimestamp(time.time()-10*24*2600).strftime("%Y-%m-%d")'),
            'localeIds' :  Code('[self.MY_LOCALE]'),
        },
        customTestCheck='''
assert_equal(True, hasattr(res.data, 'items'))
'''
    ),


}

